Package: shinyBS
Type: Package
Title: Extra Twitter Bootstrap Components for Shiny
Version: 0.65.0
Date: 2026-03-18
Authors@R: 
    c(
        person(given = "Eric", family = "Bailey", email = "ebailey@idem.in.gov", 
            role = c("aut")
        ),
        person(given = "Federico", family = "Marini", email = "marinif@uni-mainz.de", 
            role = c("cre", "ctb"), comment = c(ORCID = "0000-0003-3252-7758")),
        person(given = "Jesse", family = "Koops", email = "Jesse.Koops@cito.nl", 
            role = c("ctb")
        )
    )
Description: Adds easy access to additional Twitter Bootstrap components to Shiny. 
Imports: shiny (>= 0.13.2), htmltools, stats, jsonlite
URL: https://github.com/federicomarini/shinyBS/
BugReports: https://github.com/federicomarini/shinyBS/issues
License: GPL-3
RoxygenNote: 7.3.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-03-18 14:15:50 UTC; fede
Author: Eric Bailey [aut],
  Federico Marini [cre, ctb] (ORCID:
    <https://orcid.org/0000-0003-3252-7758>),
  Jesse Koops [ctb]
Maintainer: Federico Marini <marinif@uni-mainz.de>
Repository: CRAN
Date/Publication: 2026-03-18 15:10:02 UTC
Built: R 4.6.0; ; 2026-04-28 13:40:19 UTC; unix
